pm4py.algo.enhancement package
==============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.enhancement.comparison
   pm4py.algo.enhancement.decision
   pm4py.algo.enhancement.organizational_mining
   pm4py.algo.enhancement.resource_profiles
   pm4py.algo.enhancement.roles
   pm4py.algo.enhancement.sna

Module contents
---------------

.. automodule:: pm4py.algo.enhancement
   :members:
   :undoc-members:
   :show-inheritance:
